Module ssh — Inmanta 2017.2.1 documentation

# Module ssh

> - License: Apache 2.0
> - Version: 0.3.1
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/ssh.git

## Entities

entity `ssh::Key`

  Parents: `std::Entity`

  A public ssh-key used to access virtual machine

  attribute string `command`=''

    The command that can be executed with this public key

  attribute string `options`=''

    SSH options associated with this public key

  attribute string `name`

    An identifier for the public key

  attribute string `public_key`

    The actual public key that needs to be deployed

  relation ssh::SSHUser `ssh_users` [0:*]

    other end: `ssh::SSHUser.ssh_keys [0:*]`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `ssh::SSHServer`

  Parents: `ip::services::Server`

  A ssh server

  The following implementations are defined for this entity:

  > - `ssh::sshServer`

  The following implements statements select implementations for this entity:

  > - `ssh::sshServer`

entity `ssh::SSHUser`

  Parents: `std::Entity`

  An ssh users allows authorized keys to be installed

  attribute string `user`
  attribute string `home_dir`
  attribute string `group`
  relation std::Host `host` [1]

    other end: `std::Host.ssh_users [0:*]`

  relation ssh::Key `ssh_keys` [0:*]

    other end: `ssh::Key.ssh_users [0:*]`

  The following implementations are defined for this entity:

  > - `ssh::sshUser`

  The following implements statements select implementations for this entity:

  > - `ssh::sshUser`

## Implementations

implementation `ssh::sshServer`

implementation `ssh::sshUser`